from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Documents
import win32more.Microsoft.UI.Xaml.Input
import win32more.Microsoft.UI.Xaml.Media
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.UI.Text
class _Block_Meta_(ComPtr.__class__):
    pass
class Block(ComPtr, metaclass=_Block_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Documents.TextElement
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IBlock
    _classid_ = 'Microsoft.UI.Xaml.Documents.Block'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Block.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Block: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Microsoft.UI.Xaml.Documents.IBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Microsoft.UI.Xaml.Documents.IBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Documents.IBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Documents.IBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Microsoft.UI.Xaml.Documents.IBlock) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Microsoft.UI.Xaml.Documents.IBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IBlock) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IBlock, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_Margin(self: win32more.Microsoft.UI.Xaml.Documents.IBlock) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Margin(self: win32more.Microsoft.UI.Xaml.Documents.IBlock, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MarginProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    Margin = property(get_Margin, put_Margin)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    _Block_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _Block_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _Block_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _Block_Meta_.MarginProperty = property(get_MarginProperty, None)
    _Block_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
class BlockCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Documents.Block]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block]
    _classid_ = 'Microsoft.UI.Xaml.Documents.BlockCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], index: UInt32) -> win32more.Microsoft.UI.Xaml.Documents.Block: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Documents.Block]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], value: win32more.Microsoft.UI.Xaml.Documents.Block, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], index: UInt32, value: win32more.Microsoft.UI.Xaml.Documents.Block) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], index: UInt32, value: win32more.Microsoft.UI.Xaml.Documents.Block) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], value: win32more.Microsoft.UI.Xaml.Documents.Block) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Documents.Block]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Block], items: PassArray[win32more.Microsoft.UI.Xaml.Documents.Block]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Documents.Block]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Documents.Block]: ...
    Size = property(get_Size, None)
class Bold(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Span
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IBold
    _classid_ = 'Microsoft.UI.Xaml.Documents.Bold'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Bold.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Bold: ...
class _Glyphs_Meta_(ComPtr.__class__):
    pass
class Glyphs(ComPtr, metaclass=_Glyphs_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IGlyphs
    _classid_ = 'Microsoft.UI.Xaml.Documents.Glyphs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Glyphs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Glyphs: ...
    @winrt_mixinmethod
    def get_UnicodeString(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> hstr: ...
    @winrt_mixinmethod
    def put_UnicodeString(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Indices(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> hstr: ...
    @winrt_mixinmethod
    def put_Indices(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FontUri(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_FontUri(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_StyleSimulations(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> win32more.Microsoft.UI.Xaml.Media.StyleSimulations: ...
    @winrt_mixinmethod
    def put_StyleSimulations(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: win32more.Microsoft.UI.Xaml.Media.StyleSimulations) -> Void: ...
    @winrt_mixinmethod
    def get_FontRenderingEmSize(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> Double: ...
    @winrt_mixinmethod
    def put_FontRenderingEmSize(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OriginX(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> Double: ...
    @winrt_mixinmethod
    def put_OriginX(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OriginY(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> Double: ...
    @winrt_mixinmethod
    def put_OriginY(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Fill(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Fill(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ColorFontPaletteIndex(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs) -> Int32: ...
    @winrt_mixinmethod
    def put_ColorFontPaletteIndex(self: win32more.Microsoft.UI.Xaml.Documents.IGlyphs, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_UnicodeStringProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IndicesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontUriProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StyleSimulationsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontRenderingEmSizeProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OriginXProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OriginYProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FillProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorFontPaletteIndexProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IGlyphsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ColorFontPaletteIndex = property(get_ColorFontPaletteIndex, put_ColorFontPaletteIndex)
    Fill = property(get_Fill, put_Fill)
    FontRenderingEmSize = property(get_FontRenderingEmSize, put_FontRenderingEmSize)
    FontUri = property(get_FontUri, put_FontUri)
    Indices = property(get_Indices, put_Indices)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    OriginX = property(get_OriginX, put_OriginX)
    OriginY = property(get_OriginY, put_OriginY)
    StyleSimulations = property(get_StyleSimulations, put_StyleSimulations)
    UnicodeString = property(get_UnicodeString, put_UnicodeString)
    _Glyphs_Meta_.ColorFontPaletteIndexProperty = property(get_ColorFontPaletteIndexProperty, None)
    _Glyphs_Meta_.FillProperty = property(get_FillProperty, None)
    _Glyphs_Meta_.FontRenderingEmSizeProperty = property(get_FontRenderingEmSizeProperty, None)
    _Glyphs_Meta_.FontUriProperty = property(get_FontUriProperty, None)
    _Glyphs_Meta_.IndicesProperty = property(get_IndicesProperty, None)
    _Glyphs_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _Glyphs_Meta_.OriginXProperty = property(get_OriginXProperty, None)
    _Glyphs_Meta_.OriginYProperty = property(get_OriginYProperty, None)
    _Glyphs_Meta_.StyleSimulationsProperty = property(get_StyleSimulationsProperty, None)
    _Glyphs_Meta_.UnicodeStringProperty = property(get_UnicodeStringProperty, None)
class _Hyperlink_Meta_(ComPtr.__class__):
    pass
class Hyperlink(ComPtr, metaclass=_Hyperlink_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Documents.Span
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IHyperlink
    _classid_ = 'Microsoft.UI.Xaml.Documents.Hyperlink'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Hyperlink.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Hyperlink: ...
    @winrt_mixinmethod
    def get_NavigateUri(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_NavigateUri(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_UnderlineStyle(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.Documents.UnderlineStyle: ...
    @winrt_mixinmethod
    def put_UnderlineStyle(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.Documents.UnderlineStyle) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusLeft(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusLeft(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusRight(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusRight(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusUp(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusUp(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusDown(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_XYFocusDown(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_ElementSoundMode(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.ElementSoundMode: ...
    @winrt_mixinmethod
    def put_ElementSoundMode(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_mixinmethod
    def get_FocusState(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.FocusState: ...
    @winrt_mixinmethod
    def get_XYFocusUpNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_mixinmethod
    def put_XYFocusUpNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusDownNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_mixinmethod
    def put_XYFocusDownNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusLeftNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_mixinmethod
    def put_XYFocusLeftNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_XYFocusRightNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_mixinmethod
    def put_XYFocusRightNavigationStrategy(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_IsTabStop(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTabStop(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TabIndex(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink) -> Int32: ...
    @winrt_mixinmethod
    def put_TabIndex(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def add_Click(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.Hyperlink, win32more.Microsoft.UI.Xaml.Documents.HyperlinkClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Click(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_GotFocus(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GotFocus(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_LostFocus(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_LostFocus(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Focus(self: win32more.Microsoft.UI.Xaml.Documents.IHyperlink, value: win32more.Microsoft.UI.Xaml.FocusState) -> Boolean: ...
    @winrt_classmethod
    def get_NavigateUriProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UnderlineStyleProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusLeftProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusRightProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusUpProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusDownProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ElementSoundModeProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FocusStateProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusUpNavigationStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusDownNavigationStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusLeftNavigationStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_XYFocusRightNavigationStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTabStopProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabIndexProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    FocusState = property(get_FocusState, None)
    IsTabStop = property(get_IsTabStop, put_IsTabStop)
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
    TabIndex = property(get_TabIndex, put_TabIndex)
    UnderlineStyle = property(get_UnderlineStyle, put_UnderlineStyle)
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusDownNavigationStrategy = property(get_XYFocusDownNavigationStrategy, put_XYFocusDownNavigationStrategy)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusLeftNavigationStrategy = property(get_XYFocusLeftNavigationStrategy, put_XYFocusLeftNavigationStrategy)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusRightNavigationStrategy = property(get_XYFocusRightNavigationStrategy, put_XYFocusRightNavigationStrategy)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
    XYFocusUpNavigationStrategy = property(get_XYFocusUpNavigationStrategy, put_XYFocusUpNavigationStrategy)
    _Hyperlink_Meta_.ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    _Hyperlink_Meta_.FocusStateProperty = property(get_FocusStateProperty, None)
    _Hyperlink_Meta_.IsTabStopProperty = property(get_IsTabStopProperty, None)
    _Hyperlink_Meta_.NavigateUriProperty = property(get_NavigateUriProperty, None)
    _Hyperlink_Meta_.TabIndexProperty = property(get_TabIndexProperty, None)
    _Hyperlink_Meta_.UnderlineStyleProperty = property(get_UnderlineStyleProperty, None)
    _Hyperlink_Meta_.XYFocusDownNavigationStrategyProperty = property(get_XYFocusDownNavigationStrategyProperty, None)
    _Hyperlink_Meta_.XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    _Hyperlink_Meta_.XYFocusLeftNavigationStrategyProperty = property(get_XYFocusLeftNavigationStrategyProperty, None)
    _Hyperlink_Meta_.XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    _Hyperlink_Meta_.XYFocusRightNavigationStrategyProperty = property(get_XYFocusRightNavigationStrategyProperty, None)
    _Hyperlink_Meta_.XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    _Hyperlink_Meta_.XYFocusUpNavigationStrategyProperty = property(get_XYFocusUpNavigationStrategyProperty, None)
    _Hyperlink_Meta_.XYFocusUpProperty = property(get_XYFocusUpProperty, None)
    Click = event(add_Click, remove_Click)
    GotFocus = event(add_GotFocus, remove_GotFocus)
    LostFocus = event(add_LostFocus, remove_LostFocus)
class HyperlinkClickEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IHyperlinkClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Documents.HyperlinkClickEventArgs'
class IBlock(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IBlock'
    _iid_ = Guid('{8149d507-672f-5fd5-a10a-351389ba9659}')
    @winrt_commethod(6)
    def get_TextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(7)
    def put_TextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_HorizontalTextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(9)
    def put_HorizontalTextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(10)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_LineStackingStrategy(self) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(13)
    def put_LineStackingStrategy(self, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(14)
    def get_Margin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(15)
    def put_Margin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    Margin = property(get_Margin, put_Margin)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
class IBlockFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IBlockFactory'
    _iid_ = Guid('{21bd671c-33e2-56ef-be37-a128e898452c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Block: ...
class IBlockStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IBlockStatics'
    _iid_ = Guid('{830feedf-9aa6-56cd-983e-055500171b45}')
    @winrt_commethod(6)
    def get_TextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LineStackingStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    MarginProperty = property(get_MarginProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
class IBold(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IBold'
    _iid_ = Guid('{241a5f5a-c164-597f-b0db-fac7431297f2}')
class IGlyphs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IGlyphs'
    _iid_ = Guid('{0fbf8cfe-18e7-5e45-9fa3-d2d0927958f4}')
    @winrt_commethod(6)
    def get_UnicodeString(self) -> hstr: ...
    @winrt_commethod(7)
    def put_UnicodeString(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Indices(self) -> hstr: ...
    @winrt_commethod(9)
    def put_Indices(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_FontUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_FontUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(12)
    def get_StyleSimulations(self) -> win32more.Microsoft.UI.Xaml.Media.StyleSimulations: ...
    @winrt_commethod(13)
    def put_StyleSimulations(self, value: win32more.Microsoft.UI.Xaml.Media.StyleSimulations) -> Void: ...
    @winrt_commethod(14)
    def get_FontRenderingEmSize(self) -> Double: ...
    @winrt_commethod(15)
    def put_FontRenderingEmSize(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_OriginX(self) -> Double: ...
    @winrt_commethod(17)
    def put_OriginX(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_OriginY(self) -> Double: ...
    @winrt_commethod(19)
    def put_OriginY(self, value: Double) -> Void: ...
    @winrt_commethod(20)
    def get_Fill(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(21)
    def put_Fill(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(22)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_ColorFontPaletteIndex(self) -> Int32: ...
    @winrt_commethod(25)
    def put_ColorFontPaletteIndex(self, value: Int32) -> Void: ...
    ColorFontPaletteIndex = property(get_ColorFontPaletteIndex, put_ColorFontPaletteIndex)
    Fill = property(get_Fill, put_Fill)
    FontRenderingEmSize = property(get_FontRenderingEmSize, put_FontRenderingEmSize)
    FontUri = property(get_FontUri, put_FontUri)
    Indices = property(get_Indices, put_Indices)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    OriginX = property(get_OriginX, put_OriginX)
    OriginY = property(get_OriginY, put_OriginY)
    StyleSimulations = property(get_StyleSimulations, put_StyleSimulations)
    UnicodeString = property(get_UnicodeString, put_UnicodeString)
class IGlyphsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IGlyphsStatics'
    _iid_ = Guid('{8d9e241a-3e0e-5100-8ede-e008034ff8ae}')
    @winrt_commethod(6)
    def get_UnicodeStringProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IndicesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontUriProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StyleSimulationsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontRenderingEmSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_OriginXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_OriginYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_FillProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsColorFontEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ColorFontPaletteIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ColorFontPaletteIndexProperty = property(get_ColorFontPaletteIndexProperty, None)
    FillProperty = property(get_FillProperty, None)
    FontRenderingEmSizeProperty = property(get_FontRenderingEmSizeProperty, None)
    FontUriProperty = property(get_FontUriProperty, None)
    IndicesProperty = property(get_IndicesProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    OriginXProperty = property(get_OriginXProperty, None)
    OriginYProperty = property(get_OriginYProperty, None)
    StyleSimulationsProperty = property(get_StyleSimulationsProperty, None)
    UnicodeStringProperty = property(get_UnicodeStringProperty, None)
class IHyperlink(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IHyperlink'
    _iid_ = Guid('{ac09bd16-cdfa-54c2-8d03-a474181545b1}')
    @winrt_commethod(6)
    def get_NavigateUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_NavigateUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_UnderlineStyle(self) -> win32more.Microsoft.UI.Xaml.Documents.UnderlineStyle: ...
    @winrt_commethod(9)
    def put_UnderlineStyle(self, value: win32more.Microsoft.UI.Xaml.Documents.UnderlineStyle) -> Void: ...
    @winrt_commethod(10)
    def get_XYFocusLeft(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(11)
    def put_XYFocusLeft(self, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(12)
    def get_XYFocusRight(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(13)
    def put_XYFocusRight(self, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(14)
    def get_XYFocusUp(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(15)
    def put_XYFocusUp(self, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(16)
    def get_XYFocusDown(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(17)
    def put_XYFocusDown(self, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(18)
    def get_ElementSoundMode(self) -> win32more.Microsoft.UI.Xaml.ElementSoundMode: ...
    @winrt_commethod(19)
    def put_ElementSoundMode(self, value: win32more.Microsoft.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_commethod(20)
    def get_FocusState(self) -> win32more.Microsoft.UI.Xaml.FocusState: ...
    @winrt_commethod(21)
    def get_XYFocusUpNavigationStrategy(self) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_commethod(22)
    def put_XYFocusUpNavigationStrategy(self, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_commethod(23)
    def get_XYFocusDownNavigationStrategy(self) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_commethod(24)
    def put_XYFocusDownNavigationStrategy(self, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_commethod(25)
    def get_XYFocusLeftNavigationStrategy(self) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_commethod(26)
    def put_XYFocusLeftNavigationStrategy(self, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_commethod(27)
    def get_XYFocusRightNavigationStrategy(self) -> win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy: ...
    @winrt_commethod(28)
    def put_XYFocusRightNavigationStrategy(self, value: win32more.Microsoft.UI.Xaml.Input.XYFocusNavigationStrategy) -> Void: ...
    @winrt_commethod(29)
    def get_IsTabStop(self) -> Boolean: ...
    @winrt_commethod(30)
    def put_IsTabStop(self, value: Boolean) -> Void: ...
    @winrt_commethod(31)
    def get_TabIndex(self) -> Int32: ...
    @winrt_commethod(32)
    def put_TabIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(33)
    def add_Click(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.Hyperlink, win32more.Microsoft.UI.Xaml.Documents.HyperlinkClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(34)
    def remove_Click(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(35)
    def add_GotFocus(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(36)
    def remove_GotFocus(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(37)
    def add_LostFocus(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(38)
    def remove_LostFocus(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(39)
    def Focus(self, value: win32more.Microsoft.UI.Xaml.FocusState) -> Boolean: ...
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    FocusState = property(get_FocusState, None)
    IsTabStop = property(get_IsTabStop, put_IsTabStop)
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
    TabIndex = property(get_TabIndex, put_TabIndex)
    UnderlineStyle = property(get_UnderlineStyle, put_UnderlineStyle)
    XYFocusDown = property(get_XYFocusDown, put_XYFocusDown)
    XYFocusDownNavigationStrategy = property(get_XYFocusDownNavigationStrategy, put_XYFocusDownNavigationStrategy)
    XYFocusLeft = property(get_XYFocusLeft, put_XYFocusLeft)
    XYFocusLeftNavigationStrategy = property(get_XYFocusLeftNavigationStrategy, put_XYFocusLeftNavigationStrategy)
    XYFocusRight = property(get_XYFocusRight, put_XYFocusRight)
    XYFocusRightNavigationStrategy = property(get_XYFocusRightNavigationStrategy, put_XYFocusRightNavigationStrategy)
    XYFocusUp = property(get_XYFocusUp, put_XYFocusUp)
    XYFocusUpNavigationStrategy = property(get_XYFocusUpNavigationStrategy, put_XYFocusUpNavigationStrategy)
    Click = event(add_Click, remove_Click)
    GotFocus = event(add_GotFocus, remove_GotFocus)
    LostFocus = event(add_LostFocus, remove_LostFocus)
class IHyperlinkClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IHyperlinkClickEventArgs'
    _iid_ = Guid('{f8f89552-873d-5ef5-82bf-c79a9509b07c}')
class IHyperlinkStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IHyperlinkStatics'
    _iid_ = Guid('{e13598f4-7bc7-5ab9-885b-70f32f8c9531}')
    @winrt_commethod(6)
    def get_NavigateUriProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_UnderlineStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_XYFocusLeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_XYFocusRightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_XYFocusUpProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_XYFocusDownProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ElementSoundModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_FocusStateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_XYFocusUpNavigationStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_XYFocusDownNavigationStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_XYFocusLeftNavigationStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_XYFocusRightNavigationStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_IsTabStopProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_TabIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    FocusStateProperty = property(get_FocusStateProperty, None)
    IsTabStopProperty = property(get_IsTabStopProperty, None)
    NavigateUriProperty = property(get_NavigateUriProperty, None)
    TabIndexProperty = property(get_TabIndexProperty, None)
    UnderlineStyleProperty = property(get_UnderlineStyleProperty, None)
    XYFocusDownNavigationStrategyProperty = property(get_XYFocusDownNavigationStrategyProperty, None)
    XYFocusDownProperty = property(get_XYFocusDownProperty, None)
    XYFocusLeftNavigationStrategyProperty = property(get_XYFocusLeftNavigationStrategyProperty, None)
    XYFocusLeftProperty = property(get_XYFocusLeftProperty, None)
    XYFocusRightNavigationStrategyProperty = property(get_XYFocusRightNavigationStrategyProperty, None)
    XYFocusRightProperty = property(get_XYFocusRightProperty, None)
    XYFocusUpNavigationStrategyProperty = property(get_XYFocusUpNavigationStrategyProperty, None)
    XYFocusUpProperty = property(get_XYFocusUpProperty, None)
class IInline(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IInline'
    _iid_ = Guid('{813d427a-8980-5a79-a8fa-f27919cfb24f}')
class IInlineFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IInlineFactory'
    _iid_ = Guid('{fd253a36-fa2b-5b30-89a8-9f577871ec07}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Inline: ...
class IInlineUIContainer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IInlineUIContainer'
    _iid_ = Guid('{d529bef6-c05a-5bad-85e8-640127cf86f5}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    Child = property(get_Child, put_Child)
class IItalic(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IItalic'
    _iid_ = Guid('{ca3cbebd-7a8d-5d7a-8fdf-538e8a680f6c}')
class ILineBreak(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ILineBreak'
    _iid_ = Guid('{09307599-7cc2-5f54-b106-728620c16f76}')
class IParagraph(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IParagraph'
    _iid_ = Guid('{9ed64c77-329d-502f-a257-f58398edab51}')
    @winrt_commethod(6)
    def get_Inlines(self) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_commethod(7)
    def get_TextIndent(self) -> Double: ...
    @winrt_commethod(8)
    def put_TextIndent(self, value: Double) -> Void: ...
    Inlines = property(get_Inlines, None)
    TextIndent = property(get_TextIndent, put_TextIndent)
class IParagraphStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IParagraphStatics'
    _iid_ = Guid('{4eb89ab1-66c8-5fc0-aa5f-48c8092ceb5f}')
    @winrt_commethod(6)
    def get_TextIndentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    TextIndentProperty = property(get_TextIndentProperty, None)
class IRun(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IRun'
    _iid_ = Guid('{1f905239-37cb-590b-9132-3ffb7741906e}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_FlowDirection(self) -> win32more.Microsoft.UI.Xaml.FlowDirection: ...
    @winrt_commethod(9)
    def put_FlowDirection(self, value: win32more.Microsoft.UI.Xaml.FlowDirection) -> Void: ...
    FlowDirection = property(get_FlowDirection, put_FlowDirection)
    Text = property(get_Text, put_Text)
class IRunStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IRunStatics'
    _iid_ = Guid('{051b3c5b-7600-51a5-80c5-93eb50fd684f}')
    @winrt_commethod(6)
    def get_FlowDirectionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FlowDirectionProperty = property(get_FlowDirectionProperty, None)
class ISpan(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ISpan'
    _iid_ = Guid('{91b93d4d-4e28-57b9-bffb-3566c2a3c2a1}')
    @winrt_commethod(6)
    def get_Inlines(self) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_commethod(7)
    def put_Inlines(self, value: win32more.Microsoft.UI.Xaml.Documents.InlineCollection) -> Void: ...
    Inlines = property(get_Inlines, put_Inlines)
class ISpanFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ISpanFactory'
    _iid_ = Guid('{a6e87c16-c175-55c8-bbd3-ce40f9d0a680}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Span: ...
class ITextElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextElement'
    _iid_ = Guid('{a122ba22-833f-5220-a47e-6cd507531abe}')
    @winrt_commethod(6)
    def get_Name(self) -> hstr: ...
    @winrt_commethod(7)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(8)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(9)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(10)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(11)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(12)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(13)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(14)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(15)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(16)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(17)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(18)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(19)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(20)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(21)
    def get_Language(self) -> hstr: ...
    @winrt_commethod(22)
    def put_Language(self, value: hstr) -> Void: ...
    @winrt_commethod(23)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(24)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(25)
    def get_TextDecorations(self) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_commethod(26)
    def put_TextDecorations(self, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_commethod(27)
    def get_ContentStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(28)
    def get_ContentEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(29)
    def get_ElementStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(30)
    def get_ElementEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(31)
    def get_AllowFocusOnInteraction(self) -> Boolean: ...
    @winrt_commethod(32)
    def put_AllowFocusOnInteraction(self, value: Boolean) -> Void: ...
    @winrt_commethod(33)
    def get_AccessKey(self) -> hstr: ...
    @winrt_commethod(34)
    def put_AccessKey(self, value: hstr) -> Void: ...
    @winrt_commethod(35)
    def get_ExitDisplayModeOnAccessKeyInvoked(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_ExitDisplayModeOnAccessKeyInvoked(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_IsAccessKeyScope(self) -> Boolean: ...
    @winrt_commethod(38)
    def put_IsAccessKeyScope(self, value: Boolean) -> Void: ...
    @winrt_commethod(39)
    def get_AccessKeyScopeOwner(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(40)
    def put_AccessKeyScopeOwner(self, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(41)
    def get_KeyTipPlacementMode(self) -> win32more.Microsoft.UI.Xaml.Input.KeyTipPlacementMode: ...
    @winrt_commethod(42)
    def put_KeyTipPlacementMode(self, value: win32more.Microsoft.UI.Xaml.Input.KeyTipPlacementMode) -> Void: ...
    @winrt_commethod(43)
    def get_KeyTipHorizontalOffset(self) -> Double: ...
    @winrt_commethod(44)
    def put_KeyTipHorizontalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(45)
    def get_KeyTipVerticalOffset(self) -> Double: ...
    @winrt_commethod(46)
    def put_KeyTipVerticalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(47)
    def get_XamlRoot(self) -> win32more.Microsoft.UI.Xaml.XamlRoot: ...
    @winrt_commethod(48)
    def put_XamlRoot(self, value: win32more.Microsoft.UI.Xaml.XamlRoot) -> Void: ...
    @winrt_commethod(49)
    def add_AccessKeyDisplayRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(50)
    def remove_AccessKeyDisplayRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(51)
    def add_AccessKeyDisplayDismissed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_AccessKeyDisplayDismissed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_AccessKeyInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_AccessKeyInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(55)
    def FindName(self, name: hstr) -> IInspectable: ...
    AccessKey = property(get_AccessKey, put_AccessKey)
    AccessKeyScopeOwner = property(get_AccessKeyScopeOwner, put_AccessKeyScopeOwner)
    AllowFocusOnInteraction = property(get_AllowFocusOnInteraction, put_AllowFocusOnInteraction)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    ElementEnd = property(get_ElementEnd, None)
    ElementStart = property(get_ElementStart, None)
    ExitDisplayModeOnAccessKeyInvoked = property(get_ExitDisplayModeOnAccessKeyInvoked, put_ExitDisplayModeOnAccessKeyInvoked)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    IsAccessKeyScope = property(get_IsAccessKeyScope, put_IsAccessKeyScope)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    KeyTipHorizontalOffset = property(get_KeyTipHorizontalOffset, put_KeyTipHorizontalOffset)
    KeyTipPlacementMode = property(get_KeyTipPlacementMode, put_KeyTipPlacementMode)
    KeyTipVerticalOffset = property(get_KeyTipVerticalOffset, put_KeyTipVerticalOffset)
    Language = property(get_Language, put_Language)
    Name = property(get_Name, None)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    XamlRoot = property(get_XamlRoot, put_XamlRoot)
    AccessKeyDisplayDismissed = event(add_AccessKeyDisplayDismissed, remove_AccessKeyDisplayDismissed)
    AccessKeyDisplayRequested = event(add_AccessKeyDisplayRequested, remove_AccessKeyDisplayRequested)
    AccessKeyInvoked = event(add_AccessKeyInvoked, remove_AccessKeyInvoked)
class ITextElementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextElementFactory'
    _iid_ = Guid('{df51fb95-a5e6-5b16-8e88-9f7cbfa234b1}')
class ITextElementOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextElementOverrides'
    _iid_ = Guid('{41b01380-e49f-5fda-8c72-acc1ac1e91df}')
    @winrt_commethod(6)
    def OnDisconnectVisualChildren(self) -> Void: ...
class ITextElementStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextElementStatics'
    _iid_ = Guid('{c9b55919-e1fe-5acd-bac7-c9d7f413b35c}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CharacterSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_LanguageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TextDecorationsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_AllowFocusOnInteractionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_AccessKeyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_ExitDisplayModeOnAccessKeyInvokedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsAccessKeyScopeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_AccessKeyScopeOwnerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_KeyTipPlacementModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_KeyTipHorizontalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_KeyTipVerticalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AccessKeyProperty = property(get_AccessKeyProperty, None)
    AccessKeyScopeOwnerProperty = property(get_AccessKeyScopeOwnerProperty, None)
    AllowFocusOnInteractionProperty = property(get_AllowFocusOnInteractionProperty, None)
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    ExitDisplayModeOnAccessKeyInvokedProperty = property(get_ExitDisplayModeOnAccessKeyInvokedProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    IsAccessKeyScopeProperty = property(get_IsAccessKeyScopeProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    KeyTipHorizontalOffsetProperty = property(get_KeyTipHorizontalOffsetProperty, None)
    KeyTipPlacementModeProperty = property(get_KeyTipPlacementModeProperty, None)
    KeyTipVerticalOffsetProperty = property(get_KeyTipVerticalOffsetProperty, None)
    LanguageProperty = property(get_LanguageProperty, None)
    TextDecorationsProperty = property(get_TextDecorationsProperty, None)
class ITextHighlighter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextHighlighter'
    _iid_ = Guid('{b756e861-1d2b-5f6f-81fd-c51a5bc068ff}')
    @winrt_commethod(6)
    def get_Ranges(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextRange]: ...
    @winrt_commethod(7)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(8)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(9)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(10)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    Background = property(get_Background, put_Background)
    Foreground = property(get_Foreground, put_Foreground)
    Ranges = property(get_Ranges, None)
class ITextHighlighterBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextHighlighterBase'
    _iid_ = Guid('{5c21aaf0-3a17-5468-8aac-be14db0ed8c1}')
class ITextHighlighterBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextHighlighterBaseFactory'
    _iid_ = Guid('{e091e461-53ab-599e-aaea-800adc72da4f}')
class ITextHighlighterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextHighlighterFactory'
    _iid_ = Guid('{69c7311f-c019-5b93-b511-81418543bab7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.TextHighlighter: ...
class ITextHighlighterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextHighlighterStatics'
    _iid_ = Guid('{4975047a-87ad-51a2-977c-e771de4f4035}')
    @winrt_commethod(6)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
class ITextPointer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITextPointer'
    _iid_ = Guid('{842eb385-ee41-5930-979b-438fa7525a51}')
    @winrt_commethod(6)
    def get_Parent(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(7)
    def get_VisualParent(self) -> win32more.Microsoft.UI.Xaml.FrameworkElement: ...
    @winrt_commethod(8)
    def get_LogicalDirection(self) -> win32more.Microsoft.UI.Xaml.Documents.LogicalDirection: ...
    @winrt_commethod(9)
    def get_Offset(self) -> Int32: ...
    @winrt_commethod(10)
    def GetCharacterRect(self, direction: win32more.Microsoft.UI.Xaml.Documents.LogicalDirection) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(11)
    def GetPositionAtOffset(self, offset: Int32, direction: win32more.Microsoft.UI.Xaml.Documents.LogicalDirection) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    LogicalDirection = property(get_LogicalDirection, None)
    Offset = property(get_Offset, None)
    Parent = property(get_Parent, None)
    VisualParent = property(get_VisualParent, None)
class ITypography(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITypography'
    _iid_ = Guid('{fa27e2e3-be5e-5d21-9a5e-90cf102af828}')
class ITypographyStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.ITypographyStatics'
    _iid_ = Guid('{55fe4535-2125-533a-ada8-27be2b9e1193}')
    @winrt_commethod(6)
    def get_AnnotationAlternatesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetAnnotationAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(8)
    def SetAnnotationAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_commethod(9)
    def get_EastAsianExpertFormsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetEastAsianExpertForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(11)
    def SetEastAsianExpertForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_EastAsianLanguageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetEastAsianLanguage(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontEastAsianLanguage: ...
    @winrt_commethod(14)
    def SetEastAsianLanguage(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontEastAsianLanguage) -> Void: ...
    @winrt_commethod(15)
    def get_EastAsianWidthsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetEastAsianWidths(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontEastAsianWidths: ...
    @winrt_commethod(17)
    def SetEastAsianWidths(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontEastAsianWidths) -> Void: ...
    @winrt_commethod(18)
    def get_StandardLigaturesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def GetStandardLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(20)
    def SetStandardLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(21)
    def get_ContextualLigaturesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def GetContextualLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(23)
    def SetContextualLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_DiscretionaryLigaturesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def GetDiscretionaryLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(26)
    def SetDiscretionaryLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(27)
    def get_HistoricalLigaturesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def GetHistoricalLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(29)
    def SetHistoricalLigatures(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_StandardSwashesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def GetStandardSwashes(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(32)
    def SetStandardSwashes(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_commethod(33)
    def get_ContextualSwashesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def GetContextualSwashes(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(35)
    def SetContextualSwashes(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_commethod(36)
    def get_ContextualAlternatesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(37)
    def GetContextualAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(38)
    def SetContextualAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(39)
    def get_StylisticAlternatesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(40)
    def GetStylisticAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(41)
    def SetStylisticAlternates(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_commethod(42)
    def get_StylisticSet1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(43)
    def GetStylisticSet1(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(44)
    def SetStylisticSet1(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(45)
    def get_StylisticSet2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(46)
    def GetStylisticSet2(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(47)
    def SetStylisticSet2(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(48)
    def get_StylisticSet3Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(49)
    def GetStylisticSet3(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(50)
    def SetStylisticSet3(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(51)
    def get_StylisticSet4Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(52)
    def GetStylisticSet4(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(53)
    def SetStylisticSet4(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(54)
    def get_StylisticSet5Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(55)
    def GetStylisticSet5(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(56)
    def SetStylisticSet5(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(57)
    def get_StylisticSet6Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(58)
    def GetStylisticSet6(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(59)
    def SetStylisticSet6(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(60)
    def get_StylisticSet7Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(61)
    def GetStylisticSet7(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(62)
    def SetStylisticSet7(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(63)
    def get_StylisticSet8Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(64)
    def GetStylisticSet8(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(65)
    def SetStylisticSet8(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(66)
    def get_StylisticSet9Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(67)
    def GetStylisticSet9(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(68)
    def SetStylisticSet9(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(69)
    def get_StylisticSet10Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(70)
    def GetStylisticSet10(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(71)
    def SetStylisticSet10(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(72)
    def get_StylisticSet11Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(73)
    def GetStylisticSet11(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(74)
    def SetStylisticSet11(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(75)
    def get_StylisticSet12Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(76)
    def GetStylisticSet12(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(77)
    def SetStylisticSet12(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(78)
    def get_StylisticSet13Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(79)
    def GetStylisticSet13(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(80)
    def SetStylisticSet13(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(81)
    def get_StylisticSet14Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(82)
    def GetStylisticSet14(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(83)
    def SetStylisticSet14(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(84)
    def get_StylisticSet15Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(85)
    def GetStylisticSet15(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(86)
    def SetStylisticSet15(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(87)
    def get_StylisticSet16Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(88)
    def GetStylisticSet16(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(89)
    def SetStylisticSet16(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(90)
    def get_StylisticSet17Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(91)
    def GetStylisticSet17(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(92)
    def SetStylisticSet17(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(93)
    def get_StylisticSet18Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(94)
    def GetStylisticSet18(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(95)
    def SetStylisticSet18(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(96)
    def get_StylisticSet19Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(97)
    def GetStylisticSet19(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(98)
    def SetStylisticSet19(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(99)
    def get_StylisticSet20Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(100)
    def GetStylisticSet20(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(101)
    def SetStylisticSet20(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(102)
    def get_CapitalsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(103)
    def GetCapitals(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontCapitals: ...
    @winrt_commethod(104)
    def SetCapitals(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontCapitals) -> Void: ...
    @winrt_commethod(105)
    def get_CapitalSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(106)
    def GetCapitalSpacing(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(107)
    def SetCapitalSpacing(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(108)
    def get_KerningProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(109)
    def GetKerning(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(110)
    def SetKerning(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(111)
    def get_CaseSensitiveFormsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(112)
    def GetCaseSensitiveForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(113)
    def SetCaseSensitiveForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(114)
    def get_HistoricalFormsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(115)
    def GetHistoricalForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(116)
    def SetHistoricalForms(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(117)
    def get_FractionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(118)
    def GetFraction(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontFraction: ...
    @winrt_commethod(119)
    def SetFraction(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontFraction) -> Void: ...
    @winrt_commethod(120)
    def get_NumeralStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(121)
    def GetNumeralStyle(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontNumeralStyle: ...
    @winrt_commethod(122)
    def SetNumeralStyle(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontNumeralStyle) -> Void: ...
    @winrt_commethod(123)
    def get_NumeralAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(124)
    def GetNumeralAlignment(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontNumeralAlignment: ...
    @winrt_commethod(125)
    def SetNumeralAlignment(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontNumeralAlignment) -> Void: ...
    @winrt_commethod(126)
    def get_SlashedZeroProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(127)
    def GetSlashedZero(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(128)
    def SetSlashedZero(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(129)
    def get_MathematicalGreekProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(130)
    def GetMathematicalGreek(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(131)
    def SetMathematicalGreek(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_commethod(132)
    def get_VariantsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(133)
    def GetVariants(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontVariants: ...
    @winrt_commethod(134)
    def SetVariants(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontVariants) -> Void: ...
    AnnotationAlternatesProperty = property(get_AnnotationAlternatesProperty, None)
    CapitalSpacingProperty = property(get_CapitalSpacingProperty, None)
    CapitalsProperty = property(get_CapitalsProperty, None)
    CaseSensitiveFormsProperty = property(get_CaseSensitiveFormsProperty, None)
    ContextualAlternatesProperty = property(get_ContextualAlternatesProperty, None)
    ContextualLigaturesProperty = property(get_ContextualLigaturesProperty, None)
    ContextualSwashesProperty = property(get_ContextualSwashesProperty, None)
    DiscretionaryLigaturesProperty = property(get_DiscretionaryLigaturesProperty, None)
    EastAsianExpertFormsProperty = property(get_EastAsianExpertFormsProperty, None)
    EastAsianLanguageProperty = property(get_EastAsianLanguageProperty, None)
    EastAsianWidthsProperty = property(get_EastAsianWidthsProperty, None)
    FractionProperty = property(get_FractionProperty, None)
    HistoricalFormsProperty = property(get_HistoricalFormsProperty, None)
    HistoricalLigaturesProperty = property(get_HistoricalLigaturesProperty, None)
    KerningProperty = property(get_KerningProperty, None)
    MathematicalGreekProperty = property(get_MathematicalGreekProperty, None)
    NumeralAlignmentProperty = property(get_NumeralAlignmentProperty, None)
    NumeralStyleProperty = property(get_NumeralStyleProperty, None)
    SlashedZeroProperty = property(get_SlashedZeroProperty, None)
    StandardLigaturesProperty = property(get_StandardLigaturesProperty, None)
    StandardSwashesProperty = property(get_StandardSwashesProperty, None)
    StylisticAlternatesProperty = property(get_StylisticAlternatesProperty, None)
    StylisticSet10Property = property(get_StylisticSet10Property, None)
    StylisticSet11Property = property(get_StylisticSet11Property, None)
    StylisticSet12Property = property(get_StylisticSet12Property, None)
    StylisticSet13Property = property(get_StylisticSet13Property, None)
    StylisticSet14Property = property(get_StylisticSet14Property, None)
    StylisticSet15Property = property(get_StylisticSet15Property, None)
    StylisticSet16Property = property(get_StylisticSet16Property, None)
    StylisticSet17Property = property(get_StylisticSet17Property, None)
    StylisticSet18Property = property(get_StylisticSet18Property, None)
    StylisticSet19Property = property(get_StylisticSet19Property, None)
    StylisticSet1Property = property(get_StylisticSet1Property, None)
    StylisticSet20Property = property(get_StylisticSet20Property, None)
    StylisticSet2Property = property(get_StylisticSet2Property, None)
    StylisticSet3Property = property(get_StylisticSet3Property, None)
    StylisticSet4Property = property(get_StylisticSet4Property, None)
    StylisticSet5Property = property(get_StylisticSet5Property, None)
    StylisticSet6Property = property(get_StylisticSet6Property, None)
    StylisticSet7Property = property(get_StylisticSet7Property, None)
    StylisticSet8Property = property(get_StylisticSet8Property, None)
    StylisticSet9Property = property(get_StylisticSet9Property, None)
    VariantsProperty = property(get_VariantsProperty, None)
class IUnderline(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Documents.IUnderline'
    _iid_ = Guid('{68aaec6e-ea71-5ed2-b83e-91684b25efb9}')
class Inline(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.TextElement
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IInline
    _classid_ = 'Microsoft.UI.Xaml.Documents.Inline'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Inline.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Documents.IInlineFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Inline: ...
class InlineCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Documents.Inline]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline]
    _classid_ = 'Microsoft.UI.Xaml.Documents.InlineCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], index: UInt32) -> win32more.Microsoft.UI.Xaml.Documents.Inline: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Documents.Inline]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], value: win32more.Microsoft.UI.Xaml.Documents.Inline, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], index: UInt32, value: win32more.Microsoft.UI.Xaml.Documents.Inline) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], index: UInt32, value: win32more.Microsoft.UI.Xaml.Documents.Inline) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], value: win32more.Microsoft.UI.Xaml.Documents.Inline) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.Inline], items: PassArray[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Documents.Inline]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Documents.Inline]: ...
    Size = property(get_Size, None)
class InlineUIContainer(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Inline
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IInlineUIContainer
    _classid_ = 'Microsoft.UI.Xaml.Documents.InlineUIContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.InlineUIContainer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.InlineUIContainer: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Microsoft.UI.Xaml.Documents.IInlineUIContainer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Microsoft.UI.Xaml.Documents.IInlineUIContainer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    Child = property(get_Child, put_Child)
class Italic(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Span
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IItalic
    _classid_ = 'Microsoft.UI.Xaml.Documents.Italic'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Italic.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Italic: ...
class LineBreak(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Inline
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ILineBreak
    _classid_ = 'Microsoft.UI.Xaml.Documents.LineBreak'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.LineBreak.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.LineBreak: ...
class LogicalDirection(Enum, Int32):
    Backward = 0
    Forward = 1
class _Paragraph_Meta_(ComPtr.__class__):
    pass
class Paragraph(ComPtr, metaclass=_Paragraph_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Documents.Block
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IParagraph
    _classid_ = 'Microsoft.UI.Xaml.Documents.Paragraph'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Paragraph.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Paragraph: ...
    @winrt_mixinmethod
    def get_Inlines(self: win32more.Microsoft.UI.Xaml.Documents.IParagraph) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_mixinmethod
    def get_TextIndent(self: win32more.Microsoft.UI.Xaml.Documents.IParagraph) -> Double: ...
    @winrt_mixinmethod
    def put_TextIndent(self: win32more.Microsoft.UI.Xaml.Documents.IParagraph, value: Double) -> Void: ...
    @winrt_classmethod
    def get_TextIndentProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IParagraphStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Inlines = property(get_Inlines, None)
    TextIndent = property(get_TextIndent, put_TextIndent)
    _Paragraph_Meta_.TextIndentProperty = property(get_TextIndentProperty, None)
class _Run_Meta_(ComPtr.__class__):
    pass
class Run(ComPtr, metaclass=_Run_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Documents.Inline
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IRun
    _classid_ = 'Microsoft.UI.Xaml.Documents.Run'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Run.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Run: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Documents.IRun) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Documents.IRun, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FlowDirection(self: win32more.Microsoft.UI.Xaml.Documents.IRun) -> win32more.Microsoft.UI.Xaml.FlowDirection: ...
    @winrt_mixinmethod
    def put_FlowDirection(self: win32more.Microsoft.UI.Xaml.Documents.IRun, value: win32more.Microsoft.UI.Xaml.FlowDirection) -> Void: ...
    @winrt_classmethod
    def get_FlowDirectionProperty(cls: win32more.Microsoft.UI.Xaml.Documents.IRunStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FlowDirection = property(get_FlowDirection, put_FlowDirection)
    Text = property(get_Text, put_Text)
    _Run_Meta_.FlowDirectionProperty = property(get_FlowDirectionProperty, None)
class Span(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Inline
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ISpan
    _classid_ = 'Microsoft.UI.Xaml.Documents.Span'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Span.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Documents.ISpanFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.Span: ...
    @winrt_mixinmethod
    def get_Inlines(self: win32more.Microsoft.UI.Xaml.Documents.ISpan) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_mixinmethod
    def put_Inlines(self: win32more.Microsoft.UI.Xaml.Documents.ISpan, value: win32more.Microsoft.UI.Xaml.Documents.InlineCollection) -> Void: ...
    Inlines = property(get_Inlines, put_Inlines)
class _TextElement_Meta_(ComPtr.__class__):
    pass
class TextElement(ComPtr, metaclass=_TextElement_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ITextElement
    _classid_ = 'Microsoft.UI.Xaml.Documents.TextElement'
    @winrt_mixinmethod
    def get_Name(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> hstr: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> hstr: ...
    @winrt_mixinmethod
    def put_Language(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextDecorations(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_mixinmethod
    def put_TextDecorations(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ElementStart(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ElementEnd(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_AllowFocusOnInteraction(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowFocusOnInteraction(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AccessKey(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> hstr: ...
    @winrt_mixinmethod
    def put_AccessKey(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_ExitDisplayModeOnAccessKeyInvoked(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_ExitDisplayModeOnAccessKeyInvoked(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAccessKeyScope(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAccessKeyScope(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AccessKeyScopeOwner(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def put_AccessKeyScopeOwner(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def get_KeyTipPlacementMode(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.Input.KeyTipPlacementMode: ...
    @winrt_mixinmethod
    def put_KeyTipPlacementMode(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Microsoft.UI.Xaml.Input.KeyTipPlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_KeyTipHorizontalOffset(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Double: ...
    @winrt_mixinmethod
    def put_KeyTipHorizontalOffset(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_KeyTipVerticalOffset(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> Double: ...
    @winrt_mixinmethod
    def put_KeyTipVerticalOffset(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_XamlRoot(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement) -> win32more.Microsoft.UI.Xaml.XamlRoot: ...
    @winrt_mixinmethod
    def put_XamlRoot(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, value: win32more.Microsoft.UI.Xaml.XamlRoot) -> Void: ...
    @winrt_mixinmethod
    def add_AccessKeyDisplayRequested(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyDisplayRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AccessKeyDisplayRequested(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AccessKeyDisplayDismissed(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyDisplayDismissedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AccessKeyDisplayDismissed(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AccessKeyInvoked(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Documents.TextElement, win32more.Microsoft.UI.Xaml.Input.AccessKeyInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AccessKeyInvoked(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def FindName(self: win32more.Microsoft.UI.Xaml.Documents.ITextElement, name: hstr) -> IInspectable: ...
    @winrt_mixinmethod
    def OnDisconnectVisualChildren(self: win32more.Microsoft.UI.Xaml.Documents.ITextElementOverrides) -> Void: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LanguageProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextDecorationsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AllowFocusOnInteractionProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AccessKeyProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExitDisplayModeOnAccessKeyInvokedProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAccessKeyScopeProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AccessKeyScopeOwnerProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyTipPlacementModeProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyTipHorizontalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyTipVerticalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AccessKey = property(get_AccessKey, put_AccessKey)
    AccessKeyScopeOwner = property(get_AccessKeyScopeOwner, put_AccessKeyScopeOwner)
    AllowFocusOnInteraction = property(get_AllowFocusOnInteraction, put_AllowFocusOnInteraction)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    ElementEnd = property(get_ElementEnd, None)
    ElementStart = property(get_ElementStart, None)
    ExitDisplayModeOnAccessKeyInvoked = property(get_ExitDisplayModeOnAccessKeyInvoked, put_ExitDisplayModeOnAccessKeyInvoked)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    IsAccessKeyScope = property(get_IsAccessKeyScope, put_IsAccessKeyScope)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    KeyTipHorizontalOffset = property(get_KeyTipHorizontalOffset, put_KeyTipHorizontalOffset)
    KeyTipPlacementMode = property(get_KeyTipPlacementMode, put_KeyTipPlacementMode)
    KeyTipVerticalOffset = property(get_KeyTipVerticalOffset, put_KeyTipVerticalOffset)
    Language = property(get_Language, put_Language)
    Name = property(get_Name, None)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    XamlRoot = property(get_XamlRoot, put_XamlRoot)
    _TextElement_Meta_.AccessKeyProperty = property(get_AccessKeyProperty, None)
    _TextElement_Meta_.AccessKeyScopeOwnerProperty = property(get_AccessKeyScopeOwnerProperty, None)
    _TextElement_Meta_.AllowFocusOnInteractionProperty = property(get_AllowFocusOnInteractionProperty, None)
    _TextElement_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _TextElement_Meta_.ExitDisplayModeOnAccessKeyInvokedProperty = property(get_ExitDisplayModeOnAccessKeyInvokedProperty, None)
    _TextElement_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _TextElement_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _TextElement_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _TextElement_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _TextElement_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _TextElement_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _TextElement_Meta_.IsAccessKeyScopeProperty = property(get_IsAccessKeyScopeProperty, None)
    _TextElement_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _TextElement_Meta_.KeyTipHorizontalOffsetProperty = property(get_KeyTipHorizontalOffsetProperty, None)
    _TextElement_Meta_.KeyTipPlacementModeProperty = property(get_KeyTipPlacementModeProperty, None)
    _TextElement_Meta_.KeyTipVerticalOffsetProperty = property(get_KeyTipVerticalOffsetProperty, None)
    _TextElement_Meta_.LanguageProperty = property(get_LanguageProperty, None)
    _TextElement_Meta_.TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    AccessKeyDisplayDismissed = event(add_AccessKeyDisplayDismissed, remove_AccessKeyDisplayDismissed)
    AccessKeyDisplayRequested = event(add_AccessKeyDisplayRequested, remove_AccessKeyDisplayRequested)
    AccessKeyInvoked = event(add_AccessKeyInvoked, remove_AccessKeyInvoked)
class _TextHighlighter_Meta_(ComPtr.__class__):
    pass
class TextHighlighter(ComPtr, metaclass=_TextHighlighter_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter
    _classid_ = 'Microsoft.UI.Xaml.Documents.TextHighlighter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.TextHighlighter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Documents.TextHighlighter: ...
    @winrt_mixinmethod
    def get_Ranges(self: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextRange]: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighter, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    Foreground = property(get_Foreground, put_Foreground)
    Ranges = property(get_Ranges, None)
    _TextHighlighter_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _TextHighlighter_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
class TextHighlighterBase(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ITextHighlighterBase
    _classid_ = 'Microsoft.UI.Xaml.Documents.TextHighlighterBase'
class TextPointer(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ITextPointer
    _classid_ = 'Microsoft.UI.Xaml.Documents.TextPointer'
    @winrt_mixinmethod
    def get_Parent(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def get_VisualParent(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer) -> win32more.Microsoft.UI.Xaml.FrameworkElement: ...
    @winrt_mixinmethod
    def get_LogicalDirection(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer) -> win32more.Microsoft.UI.Xaml.Documents.LogicalDirection: ...
    @winrt_mixinmethod
    def get_Offset(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer) -> Int32: ...
    @winrt_mixinmethod
    def GetCharacterRect(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer, direction: win32more.Microsoft.UI.Xaml.Documents.LogicalDirection) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def GetPositionAtOffset(self: win32more.Microsoft.UI.Xaml.Documents.ITextPointer, offset: Int32, direction: win32more.Microsoft.UI.Xaml.Documents.LogicalDirection) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    LogicalDirection = property(get_LogicalDirection, None)
    Offset = property(get_Offset, None)
    Parent = property(get_Parent, None)
    VisualParent = property(get_VisualParent, None)
class TextRange(Structure):
    _name_ = 'Microsoft.UI.Xaml.Documents.TextRange'
    StartIndex: Int32
    Length: Int32
class _Typography_Meta_(ComPtr.__class__):
    pass
class Typography(ComPtr, metaclass=_Typography_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Documents.ITypography
    _classid_ = 'Microsoft.UI.Xaml.Documents.Typography'
    @winrt_classmethod
    def get_AnnotationAlternatesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAnnotationAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_classmethod
    def SetAnnotationAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_EastAsianExpertFormsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetEastAsianExpertForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetEastAsianExpertForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_EastAsianLanguageProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetEastAsianLanguage(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontEastAsianLanguage: ...
    @winrt_classmethod
    def SetEastAsianLanguage(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontEastAsianLanguage) -> Void: ...
    @winrt_classmethod
    def get_EastAsianWidthsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetEastAsianWidths(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontEastAsianWidths: ...
    @winrt_classmethod
    def SetEastAsianWidths(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontEastAsianWidths) -> Void: ...
    @winrt_classmethod
    def get_StandardLigaturesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStandardLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStandardLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_ContextualLigaturesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetContextualLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetContextualLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_DiscretionaryLigaturesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetDiscretionaryLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetDiscretionaryLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HistoricalLigaturesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHistoricalLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetHistoricalLigatures(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StandardSwashesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStandardSwashes(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_classmethod
    def SetStandardSwashes(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ContextualSwashesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetContextualSwashes(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_classmethod
    def SetContextualSwashes(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ContextualAlternatesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetContextualAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetContextualAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticAlternatesProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_classmethod
    def SetStylisticAlternates(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet1Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet1(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet1(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet2Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet2(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet2(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet3Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet3(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet3(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet4Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet4(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet4(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet5Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet5(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet5(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet6Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet6(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet6(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet7Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet7(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet7(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet8Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet8(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet8(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet9Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet9(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet9(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet10Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet10(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet10(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet11Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet11(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet11(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet12Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet12(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet12(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet13Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet13(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet13(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet14Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet14(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet14(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet15Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet15(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet15(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet16Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet16(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet16(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet17Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet17(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet17(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet18Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet18(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet18(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet19Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet19(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet19(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StylisticSet20Property(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetStylisticSet20(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetStylisticSet20(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_CapitalsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetCapitals(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontCapitals: ...
    @winrt_classmethod
    def SetCapitals(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontCapitals) -> Void: ...
    @winrt_classmethod
    def get_CapitalSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetCapitalSpacing(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetCapitalSpacing(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_KerningProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetKerning(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetKerning(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_CaseSensitiveFormsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetCaseSensitiveForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetCaseSensitiveForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HistoricalFormsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHistoricalForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetHistoricalForms(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_FractionProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetFraction(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontFraction: ...
    @winrt_classmethod
    def SetFraction(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontFraction) -> Void: ...
    @winrt_classmethod
    def get_NumeralStyleProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetNumeralStyle(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontNumeralStyle: ...
    @winrt_classmethod
    def SetNumeralStyle(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontNumeralStyle) -> Void: ...
    @winrt_classmethod
    def get_NumeralAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetNumeralAlignment(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontNumeralAlignment: ...
    @winrt_classmethod
    def SetNumeralAlignment(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontNumeralAlignment) -> Void: ...
    @winrt_classmethod
    def get_SlashedZeroProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetSlashedZero(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetSlashedZero(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_MathematicalGreekProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetMathematicalGreek(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetMathematicalGreek(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_VariantsProperty(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVariants(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.FontVariants: ...
    @winrt_classmethod
    def SetVariants(cls: win32more.Microsoft.UI.Xaml.Documents.ITypographyStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.FontVariants) -> Void: ...
    _Typography_Meta_.AnnotationAlternatesProperty = property(get_AnnotationAlternatesProperty, None)
    _Typography_Meta_.CapitalSpacingProperty = property(get_CapitalSpacingProperty, None)
    _Typography_Meta_.CapitalsProperty = property(get_CapitalsProperty, None)
    _Typography_Meta_.CaseSensitiveFormsProperty = property(get_CaseSensitiveFormsProperty, None)
    _Typography_Meta_.ContextualAlternatesProperty = property(get_ContextualAlternatesProperty, None)
    _Typography_Meta_.ContextualLigaturesProperty = property(get_ContextualLigaturesProperty, None)
    _Typography_Meta_.ContextualSwashesProperty = property(get_ContextualSwashesProperty, None)
    _Typography_Meta_.DiscretionaryLigaturesProperty = property(get_DiscretionaryLigaturesProperty, None)
    _Typography_Meta_.EastAsianExpertFormsProperty = property(get_EastAsianExpertFormsProperty, None)
    _Typography_Meta_.EastAsianLanguageProperty = property(get_EastAsianLanguageProperty, None)
    _Typography_Meta_.EastAsianWidthsProperty = property(get_EastAsianWidthsProperty, None)
    _Typography_Meta_.FractionProperty = property(get_FractionProperty, None)
    _Typography_Meta_.HistoricalFormsProperty = property(get_HistoricalFormsProperty, None)
    _Typography_Meta_.HistoricalLigaturesProperty = property(get_HistoricalLigaturesProperty, None)
    _Typography_Meta_.KerningProperty = property(get_KerningProperty, None)
    _Typography_Meta_.MathematicalGreekProperty = property(get_MathematicalGreekProperty, None)
    _Typography_Meta_.NumeralAlignmentProperty = property(get_NumeralAlignmentProperty, None)
    _Typography_Meta_.NumeralStyleProperty = property(get_NumeralStyleProperty, None)
    _Typography_Meta_.SlashedZeroProperty = property(get_SlashedZeroProperty, None)
    _Typography_Meta_.StandardLigaturesProperty = property(get_StandardLigaturesProperty, None)
    _Typography_Meta_.StandardSwashesProperty = property(get_StandardSwashesProperty, None)
    _Typography_Meta_.StylisticAlternatesProperty = property(get_StylisticAlternatesProperty, None)
    _Typography_Meta_.StylisticSet10Property = property(get_StylisticSet10Property, None)
    _Typography_Meta_.StylisticSet11Property = property(get_StylisticSet11Property, None)
    _Typography_Meta_.StylisticSet12Property = property(get_StylisticSet12Property, None)
    _Typography_Meta_.StylisticSet13Property = property(get_StylisticSet13Property, None)
    _Typography_Meta_.StylisticSet14Property = property(get_StylisticSet14Property, None)
    _Typography_Meta_.StylisticSet15Property = property(get_StylisticSet15Property, None)
    _Typography_Meta_.StylisticSet16Property = property(get_StylisticSet16Property, None)
    _Typography_Meta_.StylisticSet17Property = property(get_StylisticSet17Property, None)
    _Typography_Meta_.StylisticSet18Property = property(get_StylisticSet18Property, None)
    _Typography_Meta_.StylisticSet19Property = property(get_StylisticSet19Property, None)
    _Typography_Meta_.StylisticSet1Property = property(get_StylisticSet1Property, None)
    _Typography_Meta_.StylisticSet20Property = property(get_StylisticSet20Property, None)
    _Typography_Meta_.StylisticSet2Property = property(get_StylisticSet2Property, None)
    _Typography_Meta_.StylisticSet3Property = property(get_StylisticSet3Property, None)
    _Typography_Meta_.StylisticSet4Property = property(get_StylisticSet4Property, None)
    _Typography_Meta_.StylisticSet5Property = property(get_StylisticSet5Property, None)
    _Typography_Meta_.StylisticSet6Property = property(get_StylisticSet6Property, None)
    _Typography_Meta_.StylisticSet7Property = property(get_StylisticSet7Property, None)
    _Typography_Meta_.StylisticSet8Property = property(get_StylisticSet8Property, None)
    _Typography_Meta_.StylisticSet9Property = property(get_StylisticSet9Property, None)
    _Typography_Meta_.VariantsProperty = property(get_VariantsProperty, None)
class Underline(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Documents.Span
    default_interface: win32more.Microsoft.UI.Xaml.Documents.IUnderline
    _classid_ = 'Microsoft.UI.Xaml.Documents.Underline'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Documents.Underline.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Documents.Underline: ...
class UnderlineStyle(Enum, Int32):
    None_ = 0
    Single = 1


make_ready(__name__)
